@@ -14,12 +14,12 @@ package Test::DBIx::Class::SchemaManager::Trait::SQLite; {
 			return $env_path;
 		}
 		elsif($dsn) {
-			my ($dbname) = $dsn =~ m/dbi:[^:]+:dbname=(.+)/i;
+			my ($dbname) = $self->_extract_dbname_from_dsn($dsn);
 			if($dbname) {
 				return $dbname;
 			}
 			else {
-				croak("Couldn't find dbname in sqlite dsn '$dsn'");
+				die("Couldn't find dbname in sqlite dsn '$dsn'");
 			}
 		}
 		else {
@@ -27,6 +27,13 @@ package Test::DBIx::Class::SchemaManager::Trait::SQLite; {
 		}
 	}
 
+    sub _extract_dbname_from_dsn
+    {
+        my ($self, $dsn) = @_;
+        my ($dbname) = $dsn =~ m/dbi:[^:]+:(?:dbname=)?(.+)/i;
+        return $dbname;
+    }
+
 	sub get_default_connect_info {
 		my ($self) = @_;
 		return ["dbi:SQLite:dbname=".$self->dbname,'',''];
